connection_databricks_shinyapp: A Shiny app that can be used to construct a 'spark_connect'...

View source: R/ide-snippet.R

connection_databricks_shinyappR Documentation

A Shiny app that can be used to construct a spark_connect statement

Description

A Shiny app that can be used to construct a spark_connect statement

Usage

connection_databricks_shinyapp()

Value

A Shiny app


pysparklyr documentation built on April 21, 2026, 1:07 a.m.