Learn R Programming

pysparklyr (version 0.2.0)

connection_databricks_shinyapp: A Shiny app that can be used to construct a spark_connect statement

Description

A Shiny app that can be used to construct a spark_connect statement

Usage

connection_databricks_shinyapp()

Arguments

Value

A Shiny app