View source: R/start-stop-service.R
| spark_connect_service_start | R Documentation |
Starts and stops Spark Connect locally
spark_connect_service_start(
version = "4.0",
scala_version = "2.13",
python_version = NULL,
python = NULL,
include_args = TRUE,
additional_args = NULL,
...
)
spark_connect_service_stop(version = "4.0", ...)
version |
Spark version to use (3.4 or above) |
scala_version |
Acceptable Scala version of packages to be loaded |
python_version |
Python version to use if a temporary Python environment will be created |
python |
Path to the Python executable to use while running (optional) |
include_args |
Flag that indicates whether to add the additional arguments to the command that starts the service. At this time, only the 'packages' argument is submitted. |
additional_args |
Vector of additional arguments to use when starting the service |
... |
Optional arguments; currently unused |
It returns messages to the console with the status of starting, and stopping the local Spark Connect service.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.