Learn R Programming

pysparklyr (version 0.2.0)

spark_connect_service_start: Starts and stops Spark Connect locally

Description

Starts and stops Spark Connect locally

Usage

spark_connect_service_start(
  version = "4.0",
  scala_version = "2.13",
  include_args = TRUE,
  ...
)

spark_connect_service_stop(version = "4.0", ...)

Value

It returns messages to the console with the status of starting, and stopping the local Spark Connect service.

Arguments

version

Spark version to use (3.4 or above)

scala_version

Acceptable Scala version of packages to be loaded

include_args

Flag that indicates whether to add the additional arguments to the command that starts the service. At this time, only the 'packages' argument is submitted.

...

Optional arguments; currently unused